==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+80"/>
        <source>Reference point</source>
        <translation>Referenzpunkt</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotieren</translation>
    </message>
    <message>
        <location filename="../Rotate.js" line="-10"/>
        <source>Center point</source>
        <translation>Zentrum</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Target point</source>
        <translation>Zielpunkt</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Rotieren Optionen</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Anzahl Kopien</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>Original &amp;löschen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>Original &amp;beibehalten</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Mehrere Kopien</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Winkel (a):</translation>
    </message>
    <message>
        <source>45.0</source>
        <translation type="obsolete">45.0</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Aktueller Layer / &amp;Attribute</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+80"/>
        <source>Reference point</source>
        <translation>Referenzpunkt</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotieren</translation>
    </message>
    <message>
        <location filename="../Rotate.js" line="-10"/>
        <source>Center point</source>
        <translation>Zentrum</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Target point</source>
        <translation>Zielpunkt</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Rotieren Optionen</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Anzahl Kopien</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>Original &amp;löschen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>Original &amp;beibehalten</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Mehrere Kopien</translation>
    </message>
    <message>
        <location line="+114"/>
        <source>Define angle using mouse cursor</source>
        <translation>Winkel mit dem Mauszeiger definieren</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Winkel (a):</translation>
    </message>
    <message>
        <source>45.0</source>
        <translation type="obsolete">45.0</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Aktueller Layer / &amp;Attribute</translation>
    </message>
</context>
</TS>
